@@ -19,7 +19,7 @@
 #ifndef _MgQStepItem_H
 #define _MgQStepItem_H
 
-#include <magics.h>
+#include "magics.h"
 
 #include "MgQ.h"
 
@@ -33,7 +33,7 @@ public:
     };
 
     MgQStepItem(MgQLayoutItem*);
-    ~MgQStepItem();
+    ~MgQStepItem() override;
 
     int id() { return id_; }
     void id(int i) { id_ = i; }
